DiffOp

Enum DiffOp 

pub enum DiffOp {
    Insert {
        id: WidgetId,
        parent: WidgetId,
        index: usize,
    },
    Remove {
        id: WidgetId,
    },
    Update {
        id: WidgetId,
    },
    Move {
        id: WidgetId,
        parent: WidgetId,
        index: usize,
    },
}
A single reconciliation operation produced by diff.

Variants



Insert

A new node id was added as a child of parent at child-list index index.

Fields

id: WidgetId

The node being inserted.

parent: WidgetId

The parent it is inserted under.

index: usize

The position within parent’s child list.



Remove

Node id (and its subtree) was removed.

Fields

id: WidgetId

The node being removed.



Update

Node id persists but one or more of its paint-relevant fields changed.

Fields

id: WidgetId

The node whose fields changed.



Move

Node id kept its parent but moved to a new index within the child list.

Fields

id: WidgetId

The node being moved.

parent: WidgetId

Its parent (unchanged).

index: usize

The new position within parent’s child list.