AlignContent

Enum AlignContent 

pub enum AlignContent {
    Start,
    Center,
    End,
    SpaceBetween,
    SpaceAround,
    SpaceEvenly,
    Stretch,
}
Distribution of multiple lines along the cross axis (analogous to justify-content but for lines, not items). Only applies when wrap != NoWrap and there is more than one line.

Variants



Start

Lines packed at the cross-axis start.



Center

Lines centred on the cross axis.



End

Lines packed at the cross-axis end.



SpaceBetween

First line at start, last at end, equal gaps between.



SpaceAround

Equal space around each line (half-size gaps at the edges).



SpaceEvenly

Equal space between and around every line.



Stretch

Lines stretched to fill the cross axis equally.