pub struct Expression {
pub terms: Vec<Term>,
pub constant: f64,
}Expand description
A linear expression: Σ coefficient·variable + constant.
Fields
terms: Vec<Term>Weighted variable terms.
constant: f64Constant offset.
Implementations
Sourceimpl Expression
impl Expression
Sourcepub fn new(terms: Vec<Term>, constant: f64) -> Self
pub fn new(terms: Vec<Term>, constant: f64) -> Self
Construct from an explicit list of terms and a constant.
Sourcepub fn from_constant(c: f64) -> Self
pub fn from_constant(c: f64) -> Self
A constant expression with no variables.
Sourcepub fn from_variable(v: Variable) -> Self
pub fn from_variable(v: Variable) -> Self
An expression representing a single variable with coefficient 1.0.