pub enum DiffOp {
Insert {
id: WidgetId,
parent: WidgetId,
index: usize,
},
Remove {
id: WidgetId,
},
Update {
id: WidgetId,
},
Move {
id: WidgetId,
parent: WidgetId,
index: usize,
},
}Expand description
A single reconciliation operation produced by diff.
Variants
Insert
A new node id was added as a child of parent at child-list index
index.
Fields
Remove
Node id (and its subtree) was removed.
Update
Node id persists but one or more of its paint-relevant fields changed.
Move
Node id kept its parent but moved to a new index within the child list.