pub enum FlexWrap {
NoWrap,
Wrap,
WrapReverse,
}Expand description
Whether and how the flex container wraps its items.
Variants
NoWrap
All items fit in a single line (CSS flex-wrap: nowrap).
Wrap
Items wrap into additional lines in the forward direction.
WrapReverse
Items wrap into additional lines in the reverse direction (lines are reversed).