pub struct PathData {
pub verbs: Vec<PathVerb>,
pub fill_rule: FillRule,
}Expand description
A resolution-independent path built from PathVerb segments.
Paths are the primitive used for arbitrary filled and stroked shapes.
Build a path with the chaining builder methods, then pass it to
DrawList::push_path or DrawList::push_stroke_path.
Fields
verbs: Vec<PathVerb>The ordered sequence of drawing verbs that define this path.
fill_rule: FillRuleThe fill rule used when rasterising filled versions of this path.
Implementations
Sourceimpl PathData
impl PathData
Sourcepub fn with_fill_rule(self, rule: FillRule) -> Self
pub fn with_fill_rule(self, rule: FillRule) -> Self
Set the FillRule on this path (builder-style).
Sourcepub fn quad_to(&mut self, ctrl: Point, end: Point) -> &mut Self
pub fn quad_to(&mut self, ctrl: Point, end: Point) -> &mut Self
Append a quadratic Bézier QuadTo verb.