pub struct Border {
pub insets: Insets,
pub color: Color,
pub style: BorderStyle,
}Expand description
A widget border: per-side widths, a colour, and a line style.
Fields
insets: InsetsPer-side border widths (logical pixels).
color: ColorBorder colour.
style: BorderStyleLine style.
Implementations
Sourceimpl Border
impl Border
Sourcepub fn new(insets: Insets, color: Color, style: BorderStyle) -> Self
pub fn new(insets: Insets, color: Color, style: BorderStyle) -> Self
A border with explicit per-side widths.
Sourcepub fn with_style(self, style: BorderStyle) -> Self
pub fn with_style(self, style: BorderStyle) -> Self
Builder: replace the line style.
Sourcepub fn with_color(self, color: Color) -> Self
pub fn with_color(self, color: Color) -> Self
Builder: replace the colour.
Sourcepub fn is_none(&self) -> bool
pub fn is_none(&self) -> bool
Returns true if the border occupies no layout space or is invisible.
Sourcepub fn content_rect(&self, rect: Rect) -> Rect
pub fn content_rect(&self, rect: Rect) -> Rect
The content rectangle after subtracting the border widths from rect.